==> qpid-common-0.12-sources.jar: org/apache/qpid/transport/SessionCommandPoint.java <==
package org.apache.qpid.transport;
/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */


import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import org.apache.qpid.transport.codec.Decoder;
import org.apache.qpid.transport.codec.Encodable;
import org.apache.qpid.transport.codec.Encoder;

import org.apache.qpid.transport.network.Frame;

import org.apache.qpid.util.Strings;




public final class SessionCommandPoint extends Method {

    public static final int TYPE = 519;

    public final int getStructType() {
        return TYPE;
    }

    public final int getSizeWidth() {
        return 0;
    }

    public final int getPackWidth() {
        return 2;
    }

    public final boolean hasPayload() {
        return false;
    }

    public final byte getEncodedTrack() {
        return Frame.L3;
    }

    public final boolean isConnectionControl()
    {
        return false;
    }

    private short packing_flags = 0;
    private int commandId;
    private long commandOffset;


    public SessionCommandPoint() {}


    public SessionCommandPoint(int commandId, long commandOffset, Option ... _options) {
        setCommandId(commandId);
        setCommandOffset(commandOffset);

        for (int i=0; i < _options.length; i++) {
            switch (_options[i]) {
            case SYNC: this.setSync(true); break;
            case BATCH: this.setBatch(true); break;
            case UNRELIABLE: this.setUnreliable(true); break;
            case NONE: break;
            default: throw new IllegalArgumentException("invalid option: " + _options[i]);
            }
        }

    }

    public <C> void dispatch(C context, MethodDelegate<C> delegate) {
        delegate.sessionCommandPoint(context, this);
    }


    public final boolean hasCommandId() {
        return (packing_flags & 256) != 0;
    }

    public final SessionCommandPoint clearCommandId() {
        packing_flags &= ~256;
        this.commandId = 0;
        this.dirty = true;
        return this;
    }

    public final int getCommandId() {
        return commandId;
    }

    public final SessionCommandPoint setCommandId(int value) {
        this.commandId = value;
        packing_flags |= 256;
        this.dirty = true;
        return this;
    }

    public final SessionCommandPoint commandId(int value) {
        return setCommandId(value);
    }

    public final boolean hasCommandOffset() {
        return (packing_flags & 512) != 0;
    }

    public final SessionCommandPoint clearCommandOffset() {
        packing_flags &= ~512;
        this.commandOffset = 0;
        this.dirty = true;
        return this;
    }

    public final long getCommandOffset() {
        return commandOffset;
    }

    public final SessionCommandPoint setCommandOffset(long value) {
        this.commandOffset = value;
        packing_flags |= 512;
        this.dirty = true;
        return this;
    }

    public final SessionCommandPoint commandOffset(long value) {
        return setCommandOffset(value);
    }




    public void write(Encoder enc)
    {
        enc.writeUint16(packing_flags);
        if ((packing_flags & 256) != 0)
            enc.writeSequenceNo(this.commandId);
        if ((packing_flags & 512) != 0)
            enc.writeUint64(this.commandOffset);

    }

    public void read(Decoder dec)
    {
        packing_flags = (short) dec.readUint16();
        if ((packing_flags & 256) != 0)
            this.commandId = dec.readSequenceNo();
        if ((packing_flags & 512) != 0)
            this.commandOffset = dec.readUint64();

    }

    public Map<String,Object> getFields()
    {
        Map<String,Object> result = new LinkedHashMap<String,Object>();

        if ((packing_flags & 256) != 0)
            result.put("commandId", getCommandId());
        if ((packing_flags & 512) != 0)
            result.put("commandOffset", getCommandOffset());


        return result;
    }

}

==> qpid-common-0.20-sources.jar: org/apache/qpid/transport/SessionCommandPoint.java <==
package org.apache.qpid.transport;
/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */


import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.qpid.transport.codec.Decoder;
import org.apache.qpid.transport.codec.Encoder;

import org.apache.qpid.transport.network.Frame;


public final class SessionCommandPoint extends Method {

    public static final int TYPE = 519;

    public final int getStructType() {
        return TYPE;
    }

    public final int getSizeWidth() {
        return 0;
    }

    public final int getPackWidth() {
        return 2;
    }

    public final boolean hasPayload() {
        return false;
    }

    public final byte getEncodedTrack() {
        return Frame.L3;
    }

    public final boolean isConnectionControl()
    {
        return false;
    }

    private short packing_flags = 0;
    private int commandId;
    private long commandOffset;


    public SessionCommandPoint() {}


    public SessionCommandPoint(int commandId, long commandOffset, Option ... _options) {
        setCommandId(commandId);
        setCommandOffset(commandOffset);

        for (int i=0; i < _options.length; i++) {
            switch (_options[i]) {
            case SYNC: this.setSync(true); break;
            case BATCH: this.setBatch(true); break;
            case UNRELIABLE: this.setUnreliable(true); break;
            case NONE: break;
            default: throw new IllegalArgumentException("invalid option: " + _options[i]);
            }
        }

    }

    public <C> void dispatch(C context, MethodDelegate<C> delegate) {
        delegate.sessionCommandPoint(context, this);
    }


    public final boolean hasCommandId() {
        return (packing_flags & 256) != 0;
    }

    public final SessionCommandPoint clearCommandId() {
        packing_flags &= ~256;
        this.commandId = 0;
        setDirty(true);
        return this;
    }

    public final int getCommandId() {
        return commandId;
    }

    public final SessionCommandPoint setCommandId(int value) {
        this.commandId = value;
        packing_flags |= 256;
        setDirty(true);
        return this;
    }

    public final SessionCommandPoint commandId(int value) {
        return setCommandId(value);
    }

    public final boolean hasCommandOffset() {
        return (packing_flags & 512) != 0;
    }

    public final SessionCommandPoint clearCommandOffset() {
        packing_flags &= ~512;
        this.commandOffset = 0;
        setDirty(true);
        return this;
    }

    public final long getCommandOffset() {
        return commandOffset;
    }

    public final SessionCommandPoint setCommandOffset(long value) {
        this.commandOffset = value;
        packing_flags |= 512;
        setDirty(true);
        return this;
    }

    public final SessionCommandPoint commandOffset(long value) {
        return setCommandOffset(value);
    }




    public void write(Encoder enc)
    {
        enc.writeUint16(packing_flags);
        if ((packing_flags & 256) != 0)
        {
            enc.writeSequenceNo(this.commandId);
        }
        if ((packing_flags & 512) != 0)
        {
            enc.writeUint64(this.commandOffset);
        }

    }

    public void read(Decoder dec)
    {
        packing_flags = (short) dec.readUint16();
        if ((packing_flags & 256) != 0)
        {
            this.commandId = dec.readSequenceNo();
        }
        if ((packing_flags & 512) != 0)
        {
            this.commandOffset = dec.readUint64();
        }

    }

    public Map<String,Object> getFields()
    {
        Map<String,Object> result = new LinkedHashMap<String,Object>();

        if ((packing_flags & 256) != 0)
        {
            result.put("commandId", getCommandId());
        }
        if ((packing_flags & 512) != 0)
        {
            result.put("commandOffset", getCommandOffset());
        }


        return result;
    }


}
